<?php
/**
 * @var \Illuminate\Database\Eloquent\Collection $users
 * @var int $page_number
 */


use Itguild\EloquentTable\EloquentDataProvider;
use Itguild\EloquentTable\ListEloquentTable;
use kernel\IGTabel\btn\PrimaryBtn;
use kernel\modules\user\models\User;
use kernel\modules\user\table\columns\UserDeleteActionColumn;
use kernel\modules\user\table\columns\UserEditActionColumn;
use kernel\modules\user\table\columns\UserViewActionColumn;

$table = new ListEloquentTable(new EloquentDataProvider(User::class, [
    'currentPage' => $page_number,
    'perPage' => 3,
    'params' => ["class" => "table table-bordered", "border" => "2"],
    'baseUrl' => "/admin/user",
    'filters' => ['email'],
]));
$table->columns([
    'username' => [
        "filter" => [
            'class' => \Itguild\Tables\Filter\InputTextFilter::class
        ]
    ],
    'created_at' => function ($data) {
        if (!$data){
            return null;
        }

        return (new DateTimeImmutable($data))->format("d-m-Y");
    },
    'updated_at' => function ($data) {
        if (!$data){
            return null;
        }

        return (new DateTimeImmutable($data))->format("d-m-Y");
    }
]);
$table->beforePrint(function () {
    return PrimaryBtn::create("Создать", "/admin/user/create")->fetch();
    //return (new PrimaryBtn("Создать", "/admin/user/create"))->fetch();
});
$table->addAction(UserViewActionColumn::class);
$table->addAction(UserEditActionColumn::class);
$table->addAction(UserDeleteActionColumn::class);
$table->create();
$table->render();